@@ -1,15 +1,22 @@
 import argparse
 import os
+import pkg_resources
 import sys
 
 from IPython import start_ipython
 
 from . import util
 
-def go():
+def parse_args_and_run():
     parser = argparse.ArgumentParser()
+    parser.add_argument('-v', '--version', action='store_true',
+                        help='Display the version number of okcupyd')
     util.add_command_line_options(parser.add_argument)
-    util.handle_command_line_options(parser.parse_args())
+    args = parser.parse_args()
+    if args.version:
+        print(pkg_resources.get_distribution('okcupyd').version)
+        sys.exit()
+    util.handle_command_line_options(args)
     util.get_credentials()
     sys.exit(start_ipython(['-i', os.path.join(os.path.dirname(__file__), 'start.py')]))
 
@@ -24,4 +31,8 @@ from .util import save_file
 
 
 __all__ = ('search', 'User', 'AttractivenessFinder', 'Statistics',
-           'save_file', 'go', 'PhotoUploader', 'Session')
+           'save_file', 'parse_args_and_run', 'PhotoUploader', 'Session')
+
+
+if __name__ == '__main__':
+    parse_args_and_run()
