@@ -216,10 +216,10 @@ class Fetchable(object):
     def items(self):
         return list(self._fetcher.fetch())
 
-    def refresh(self, use_existing=True):
+    def refresh(self, use_existing=True, stop_at=None):
         if 'items' in self.__dict__:
             self.items = list(self._fetcher.fetch(
-                existing=self.items if use_existing else ()
+                id_to_existing=self.items if use_existing else ()
             ))
         return self.threads
 
@@ -237,7 +237,9 @@ class StepObjectFetcher(object):
         self._fetcher = fetcher
         self.step = step or self._fetcher.step
 
-    def fetch(self, start_at=0, get_at_least=None, id_to_existing=None):
+    # TODO(@IvanMalison): Clean up arguments. What should the interface be?
+    def fetch(self, start_at=0, get_at_least=None, id_to_existing=None,
+              stop_at=None):
         self._processor.id_to_existing = id_to_existing
         start_at_iterator = (range(start_at + 1, get_at_least + 1, self.step)
                              if get_at_least
