@@ -43,7 +43,7 @@ def scrub_request_body(request):
 
 
 def scrub_uri(uri):
-    return uri.replace(settings.USERNAME, TESTING_USERNAME)
+    return uri.lower().replace(settings.USERNAME.lower(), TESTING_USERNAME)
 
 
 def scrub_query_string(query_string):
@@ -129,6 +129,7 @@ okcupyd_vcr = vcr.VCR(match_on=('path', 'method', 'match_search_query',
                       before_record_response=scrub_login_response,)
 okcupyd_vcr.register_matcher('body_as_query_string', body_as_query_string)
 okcupyd_vcr.register_matcher('match_search_query', match_search_query)
+match_on_no_body = list(filter(lambda x: 'body' not in x, okcupyd_vcr.match_on))
 
 
 
@@ -137,6 +138,12 @@ def cassette_path(cassette_name):
                         'vcr_cassettes', '{0}.yaml'.format(cassette_name))
 
 @util.n_partialable
-def use_cassette(cassette_name, *args, **kwargs):
+def use_cassette(function=None, cassette_name=None, *args, **kwargs):
+    if cassette_name is None:
+        assert function, 'Must supply function if no cassette name given'
+        cassette_name = function.__name__
     path = cassette_path(cassette_name)
-    return okcupyd_vcr.use_cassette(path, *args, **kwargs)
+    context_decorator = okcupyd_vcr.use_cassette(path, *args, **kwargs)
+    if function:
+        return context_decorator(function)
+    return context_decorator
